##  Advanced Fields
The advanced field allows you to incorporate conditional questions and calculated fields into the surveys.
Conditional questions: They allow you to display or skip a question based on a response given earlier. To set up a rule, select the question to which the rule should apply and then define the specific conditions. For example, you can create a conditional question like "Are you sure you are the owner of the application?" Based on the response, you can choose whether follow-up questions should be displayed or skipped.
To make a question conditional, follow these steps:
  1. From the question’s menu in the top right corner, select Manage conditionality.
  2. Define the condition by clicking Add a new condition.
  3. Click Save to apply the condition.


![Making a Question Conditional](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274e7c397a441014abe0f6d5abc59c87_LowRes.png)
Making a Question Conditional
Calculated fields: They enable you to quantify survey results by deriving a specific score by aggregating or quantifying answers provided in other questions. This functionality accepts standard JavaScript as input and is designed to return an integer. For more information, see [Calculated Fields in Surveys](https://help.sap.com/docs/leanix/ea/calculated-fields-in-surveys?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to configure calculated fields in surveys using JavaScript for advanced analysis and manipulation of data collected from survey responses.").
